@@ -1,10 +1,23 @@
 #!/usr/bin/env python3
 from flashcam.version import __version__
 from fire import Fire
-
 import json
 import os
 import sys
+"""
+ Config for all modes of use. This is a primary source, as Flask is the primary operation mode
+-------------------------------------
+ o) encoding:
+ oo) in the flow:
+   - real_camera.py  ... cv2 VideoCapture .... V4L2 ... I use YUYV lately (v 1.2.) rather than MJPG
+   - web.py          ... jpg creation with compression - COMPR = config.CONFIG['kompress']
+   - stream_enhancer ... frame  via send_image  .... should be no compression
+ oo ) recording:
+   - izmq_receiver ... IYUV ... together with AVI .....   is HUGE ( I used to save 1 frame twice?)
+   - stream_enhancer
+         - seconds < 0 => motion detect/uni ... XVID + avi
+         - seconds > 0 => laps ... XVID + avi
+"""
 # ----- port here. 5000 is flask; is moved to 8000 by gunicorn; to 80 by nginx
 CONFIG={  'filename':'~/.config/test/cfg.json',
           #'recommended':"",
@@ -12,21 +25,18 @@ CONFIG={  'filename':'~/.config/test/cfg.json',
           'product':"",
           'resolution':"640x480",
           'framekind':"direct",
-          'average':0,
           'threshold':0,
+          'average':0,
           'blur':0,
           'laps':0,
           'web5000':False,
           'expo':'auto',
-          # DEPRAC GAMMA for mmaga
-          #'gamma':'def',
           'gain':'def',
           'mmaga':'def',
           'histogram':False,
-          # 'zmqtarget':'127.0.0.1',
           'imagezmq':None,
           'jtelegram':False,
-          'kompress':95,
+          'kompress':98,
           'save':False,
 
           'qpassfile':"~/.pycamfw_userpass",
@@ -34,40 +44,15 @@ CONFIG={  'filename':'~/.config/test/cfg.json',
           'otate':0, # rotate 0
           'x':0,
           'y':0,
-
+          # debug
           'vof':110, # field of view 110 degrees default (uniwrec only)
           'zoom':1,
 
+          'XY':'1x1',  # position (uppercase)
 
           'user':'aaa',
           'password':'aaa',
-          # ------------------  things for DM ----------
-          # DEPREC target_frame  for framekind
-          #'target_frame':'direct',
-          # DEPREC TIMELAPS for laps
-          #'timelaps':3600,
-          # ----------------------
-          # ------------------ ASTRO speed compensation
-          # DEPRAC ROTATE180 for otate
-          #'rotate180':False,
-          # ------------------------
-          #-----------------------
-          #          'camera_on':False,   # quewstionable...
-          #'interpolation':'None',
-          #'mintime':0.1,       # normal picture rate
-          #'videodev':0,
           'port':5000,
-          #'change':None,
-          #'autoiris':True,
-          #'riris':1000,
-          #'pantilt':False,
-          #'pan':0,
-          #'tilt':0,
-          #'gamma_adjust':False,
-          #'rgain':0,
-          #'use_v4l':True,      # zdenek84 had a problem with. I try again
-          #'quit':False         # this is howto quit
-          #------ end with nothing
           'placeholder':False
 
 }
