@@ -197,7 +197,7 @@ class Camera(BaseCamera):
                 dsize = (width, height)
                 # resize image
                 frame = cv2.resize(image, dsize)
-                time.sleep(0.1) # from 85%cpu to 20% ??????
+                time.sleep(0.3) # from 85%cpu to 20% ??????
                 return "image", frame, cap # repeat cap==image
 
             elif cap.find("clock.jpg")==0:
@@ -219,7 +219,7 @@ class Camera(BaseCamera):
                 b,g,r,a = 0,255,0,200
                 draw.text( position,  drtext, font = font, fill = (b, g, r, a))
                 frame = np.array(img_pil)
-                time.sleep(0.1) # from 85%cpu to 20%
+                time.sleep(0.3) # from 85%cpu to 20% with 0.1;
                 # cv2.putText(
                 #     blank_image, #numpy array on which text is written
                 #     drtext, #text
@@ -240,7 +240,7 @@ class Camera(BaseCamera):
                 else:
                     print("X... image doesnt exist", cap, "using monoskop")
 
-                time.sleep(0.1) # from 85%cpu to 20%
+                time.sleep(0.3) # from 85%cpu to 20% with 0.1
                 return "image", cv2.imread( fullpath_fixed_image), cap # repeat cap==image
         else:
             #print("i...  camera mode")
