@@ -286,7 +286,7 @@ class Stream_Enhancer:
 #        self.textbox(,  [self,5] )
 
 #----------------------------------------------- DEFINE GRID HERE-------
-    def setbox(self, txt, rowcol, side="" , target = None):
+    def setbox(self, txt, rowcol, side="" , target = None, grayed = False):
         """
         uses textbox, pots on positions....
         """
@@ -377,7 +377,9 @@ class Stream_Enhancer:
                 pos[1] = self.frame.shape[0] - int(1.5*self.posy_offs)
 
         #print(pos)
-        self.textbox(txt, pos , bgcolor= self.RC_COLOR(row,col) , target = framekind)
+        bgcolor =  self.RC_COLOR(row,col)
+        if grayed: bgcolor = (120,120,120)
+        self.textbox(txt, pos , bgcolor= bgcolor , target = framekind)
 
     #-------------------------------------------- ENDOF LABELS----------
 
@@ -847,7 +849,7 @@ class Stream_Enhancer:
 
         if seconds == 0:
             return
-        elif seconds<0: # - means saving avi - motion detect or in uni...
+        elif seconds<0: # - means saving avi - motion detect or in uni...*******
 
             # trigger is old now
             # if not(self.telegramtrigger)==bool:
@@ -924,7 +926,7 @@ class Stream_Enhancer:
 
 
 
-        # -------------- timelapse if seconds>0:
+        # -------------- timelapse if seconds>0: *******************************
         elif seconds>0:
             if not self.aviopened_laps:
                 me = socket.gethostname()
