@@ -294,8 +294,11 @@ def crossonw( img,  dix, diy):
 
 
 
+# ... this i dont remember
 # --- probably a wrong guess ... @auth.verify_password
+#
 # i need  @auth.login_required
+@auth.verify_password
 @app.route("/cross", methods=['GET', 'POST'])
 # @auth.login_required
 def cross():
@@ -425,7 +428,16 @@ def cross():
         if request.form.get('live') == 'LIVE':
             mmwrite(f"fixed_image None" )
         if request.form.get('fixed') == 'FIXED':
-            mmwrite(f'fixed_image "beamon.jpg"' )
+            mmwrite(f'fixed_image "BEAM_ON_.jpg"' )
+        # added 2302 - directly image display possible via curl
+        elif  request.form.get('fixed') is not None and \
+              request.form.get('fixed').find(".jpg")>1:
+            diimg = request.form.get('fixed')
+            mmwrite(f'fixed_image "{diimg}"' )
+
+        if request.form.get('overtext') is not None:
+            digits = request.form.get('overtext')
+            mmwrite(f"overtext {digits}" )
 
 
         # ---------------------------------------------- Cross controls
